
# Data: setwd()                                                                                                                              ####
# 
# Specify the folder where you have saved the csv files:
setwd('C:/Users/...') 


# Frequencies of answer types                         (Fig 3 & Fig 4)                                                                        ####
# 
(dat <- read.csv2("PD-Face-Pareidolia_Data-frequencies.csv", header=T))  
head(dat <- as.data.frame(dat))
(tab <- xtabs(Frequency ~ ., data=dat)) # I. structured contingency table   
# 
# install.packages("vcd")
library(vcd)
structable(~ Group+Answer, data=tab);  mosaic(~ Group+Answer, data=tab, shade=T, labeling = labeling_values) 
structable(~ Group+Types, data=tab);  mosaic(~ Group+Types, data=tab, shade=T, labeling = labeling_values) 
# 
# export tiff
tiff('Fig3.tiff', units="cm", width=18, height=12, res=1200, compression = 'lzw')
structable(~ Group+Answer, data=tab);  mosaic(~ Group+Answer, data=tab, shade=T, labeling = labeling_values) 
dev.off()
# 
# export tiff
tiff('Fig4.tiff', units="cm", width=18, height=12, res=1200, compression = 'lzw')
structable(~ Group+Types, data=tab);  mosaic(~ Group+Types, data=tab, shade=T, labeling = labeling_values) 
dev.off()
# 
cotabplot(~ Group+Answer | Face, data=tab, shade=T, labeling = labeling_values)
# -> For images with a face, results become more significant, because there are more images of that type.
# 
structable(~ Group+Seen, data=tab);  mosaic(~ Group+Seen, data=tab, shade=T, labeling = labeling_values) 
# -> Interesting. Both state equally often to have found faces, but PD patients make more mistakes.
# -> Coincidence? Or is there something like an equally strong "expectation" to find faces? 


# Linear Regression                                   (Table 3 & Table 4)                                                                    ####
# 
dat <- read.csv2("PD-Face-Pareidolia_Data.csv", header=T)
dat.PD <- subset(dat, dat$group=="PD")
dat.PD[,"Stroop_err_z"]  <- as.numeric(as.character(dat.PD[,"Stroop_err_z"]))
dat.PD[,"MDS_P1"]        <- as.numeric(as.character(dat.PD[,"MDS_P1"]))
dat.PD[,"Levodopa"]      <- as.numeric(as.character(dat.PD[,"Levodopa"]))
str(dat.PD)
# 
# install.packages("regr0")
library(regr0)
(fit.type3 <- regr(type3 ~ gender + age + hallucin + Stroop_err_z + MWT + MoCa + DBS + MDS_P1, data=dat.PD))  # 0.767
(fit.type4 <- regr(type4 ~ gender + age + hallucin + Stroop_err_z + MWT + MoCa + DBS + MDS_P1, data=dat.PD))  # 0.796
# 
(fit.type3.step <- step(fit.type3, trace=F))   # 0.652; 0.000 MoCa*** 
(fit.type4.step <- step(fit.type4, trace=F))   # 0.781; 0.005 gender**, 0.014 MWT**, 0.015 hallucin*, 0.030 age* 
# 
confint(fit.type3.step)
confint(fit.type4.step)


# ROC analysis of answer types that classify an error (Fig 5)                                                                                ####
# 
dat <- read.csv2("PD-Face-Pareidolia_Data.csv", header=T)
# 
# install.packages("ROCR")
# install.packages("gplots")
library(ROCR)
library(gplots)
# 
pd1 <- prediction(dat$type1, dat$group)
pf1 <- performance(pd1, "tpr","fpr")
pd2 <- prediction(dat$type3, dat$group)
pf2 <- performance(pd2, "tpr","fpr")
pd3 <- prediction(dat$type4, dat$group)
pf3 <- performance(pd3, "tpr","fpr")
# 
plot(pf1,             lwd=2, col="blue", xlab="Specificity", ylab="Sensitivity", main="ROC for answer types that classify an error ")
plot(pf2, add = TRUE, lwd=2, col="red",)
plot(pf3, add = TRUE, lwd=2, col="green",)
abline(0, 1, lwd=2, col="grey") 
legend("bottomright", legend=c("type 1 (AUC=0.576)", "type 3 (AUC=0.676)", "type 4 (AUC=0.678)"), col=c("blue", "red", "green"), lwd=2, bty="0")
# 
# export tiff
tiff('Fig5.tiff', units="cm", width=12, height=12, res=1200, compression = 'lzw')
plot(pf1,             lwd=2, col="blue", xlab="Specificity", ylab="Sensitivity", main="ROC for answer types that classify an error ")
plot(pf2, add = TRUE, lwd=2, col="red",)
plot(pf3, add = TRUE, lwd=2, col="green",)
abline(0, 1, lwd=2, col="grey") 
legend("bottomright", legend=c("type 1 (AUC=0.576)", "type 3 (AUC=0.676)", "type 4 (AUC=0.678)"), col=c("blue", "red", "green"), lwd=2, bty="0")
dev.off()
# 
pred <- prediction(dat$wrong, dat$group)
performance(pred, "auc")@y.values
# 
boxplot(wrong ~ group, data = dat)


# Logistic regression model & ROC analysis            (Table 5 & Fig 6)                                                                      ####
# 
dat <- read.csv2("PD-Face-Pareidolia_Data.csv", header=T)
# 
# install.packages("regr0")
library(regr0)
(fit1 <- regr(group ~ type1 + type4 + type3, family=binomial, data=dat)) # anova() unnecessary for regr(), automatic likelihood ratio test 
(fit1.step <- step(fit1, trace=F))
# 
prob <- predict(fit1.step,type=c("response"))    
pd1 <- prediction(prob, dat$group)
pf1 <- performance(pd1, "tpr","fpr")
plot(pf1, lwd=2, col="purple", xlab="Specificity", ylab="Sensitivity", main="ROC for regression model")
abline(0, 1, lwd=2, col="grey") 
legend("bottomright", legend=c("types 1 & 3 (AUC=0.733)"), col=c("purple"), lwd=2, bty="0")
# 
# export tiff
tiff('Fig6.tiff', units="cm", width=12, height=12, res=1200, compression = 'lzw')
plot(pf1, lwd=2, col="purple", xlab="Specificity", ylab="Sensitivity", main="ROC for regression model")
abline(0, 1, lwd=2, col="grey") 
legend("bottomright", legend=c("types 1 & 3 (AUC=0.733)"), col=c("purple"), lwd=2, bty="0")
dev.off()

